#!/bin/sh
# This shell script takes care of starting and stopping dhcpd.
# chkconfig: 345 65 35

. /etc/init.d/functions		# Source function library.
. /etc/sysconfig/network	# Source networking configuration.

# Check that networking is up.
[ "$NETWORKING" == "yes" -a -x /usr/sbin/dhcpd -a -s /etc/dhcpd.conf ] || exit

LOCKFILE=/var/lock/subsys/dhcpd
RETVAL=0

unset DEV
for i in /etc/sysconfig/network-scripts/ifcfg-*; do
	unset DHCP
	unset DEVICE
	. $i
	[ "$DHCP" == "yes" ] && DEV="$DEV $DEVICE"
done
all=255.255.255.255

start(){
	echo -n "Starting dhcpd on $DEV:"
	daemon /usr/sbin/dhcpd $DEV
	RETVAL=$?
	echo
	if [ $RETVAL -eq 0 ]; then
#		action "Adding local broadcast host route:" \
		echo "Adding local broadcast host route..."
		for i in $DEV; do
			/sbin/route add -net $all netmask $all dev $i
		done
		touch "$LOCKFILE"
	fi
}

stop(){
	echo -n "Shutting down dhcpd: "
	killproc dhcpd
	RETVAL=$?
	echo
#	action "Removing host route defined at startup:" \
	echo "Removing host route defined at startup..."
	for i in $DEV; do
		/sbin/route del $all dev $i
	done
	[ $RETVAL -eq 0 ] && rm -f "$LOCKFILE"
}

restart(){
	stop
	start
}

# See how we were called.
case "$1" in
	start)
		start
	;;
	stop)
		stop
	;;
	restart|reload)
		restart
	;;
	condstop)
		[ -e "$LOCKFILE" ] && stop
	;;
	condrestart)
		[ -e "$LOCKFILE" ] && restart
/etc/sysconfig/network-scripts/ifcfg-eth0	;;
	status)
		status dhcpd
		RETVAL=$?
	;;
	*)
		echo "Usage: ${0##*/} {start|stop|restart|condstop|condrestart|status}"
		RETVAL=1
	;;
esac

exit $RETVAL
